@@ -1,30 +1,38 @@
-GetTarget <- function(v, target) {
-    if (is.null(target)) {target = max(v, na.rm = TRUE)}
-    return(target)
-}
-
 partitionsGeneral <- function(v, m = NULL, repetition = FALSE,
                               freqs = NULL, target = NULL, lower = NULL,
                               upper = NULL, nThreads = NULL,
                               tolerance = NULL) {
 
-    return(.Call(`_RcppAlgos_CombinatoricsCnstrt`, v, m, repetition, freqs,
-                 lower, upper, "sum", "==", GetTarget(v, target), TRUE,
-                 FALSE, FALSE, nThreads, pkgEnv$nThreads, tolerance))
+    stopifnot(is.numeric(v))
+    return(.Call(`_RcppAlgos_CombinatoricsCnstrt`, v, m, repetition,
+                 freqs, lower, upper, "sum", "==", GetTarget(v, target),
+                 TRUE, FALSE, FALSE, nThreads, pkgEnv$nThreads, tolerance,
+                 FALSE, FALSE))
 }
 
 partitionsCount <- function(v, m = NULL, repetition = FALSE,
                             freqs = NULL, target = NULL) {
-    return(.Call(`_RcppAlgos_PartitionsCount`, GetTarget(v, target), v, m,
-                 repetition, freqs, "==", NULL, NULL, FALSE, FALSE))
+
+    stopifnot(is.numeric(v))
+    return(.Call(`_RcppAlgos_PartitionsCount`, GetTarget(v, target),
+                 v, m, repetition, freqs, "==", NULL, NULL, FALSE,
+                 FALSE, FALSE, FALSE))
 }
 
 partitionsDesign <- function(v, m = NULL, repetition = FALSE,
                              freqs = NULL, target = NULL,
                              showDesign = FALSE) {
 
-    return(.Call(`_RcppAlgos_PartitionsCount`, GetTarget(v, target), v, m,
-                 repetition, freqs, "==", NULL, NULL, TRUE, showDesign))
+    stopifnot(is.numeric(v))
+    return(.Call(`_RcppAlgos_PartitionsCount`, GetTarget(v, target),
+                 v, m, repetition, freqs, "==", NULL, NULL, TRUE,
+                 showDesign, FALSE, FALSE))
+}
+
+partitionsRank <- function(..., v, repetition = FALSE,
+                           freqs = NULL, target = NULL) {
+    GetRankPart(..., v = v, repetition = repetition, freqs = freqs,
+                target = target, IsComposition = FALSE, weak = FALSE)
 }
 
 partitionsSample <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
@@ -32,6 +40,8 @@ partitionsSample <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
                              seed = NULL, nThreads = NULL,
                              namedSample = FALSE) {
 
+    stopifnot(is.numeric(v))
+
     if (!is.null(seed)) {
         set.seed(seed)
     }
@@ -39,15 +49,17 @@ partitionsSample <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
     return(.Call(`_RcppAlgos_SamplePartitions`, v, m, repetition, freqs,
                  sampleVec, seed, n, sample, FALSE, nThreads,
                  pkgEnv$nThreads, namedSample, "==",
-                 GetTarget(v, target), NULL, new.env()))
+                 GetTarget(v, target), NULL, new.env(), FALSE, FALSE))
 }
 
 partitionsIter <- function(v, m = NULL, repetition = FALSE,
                            freqs = NULL, target = NULL,
                            nThreads = NULL, tolerance = NULL) {
 
-    InitVals <- .Call(`_RcppAlgos_GetClassVals`, v, m, repetition, freqs,
-                      TRUE, NULL, nThreads, pkgEnv$nThreads, TRUE)
+    stopifnot(is.numeric(v))
+    InitVals <- .Call(`_RcppAlgos_GetClassVals`, v, m, repetition,
+                      freqs, TRUE, NULL, nThreads, pkgEnv$nThreads,
+                      TRUE, FALSE, FALSE)
 
     new("Partitions", InitVals, FALSE, "sum", "==",
         GetTarget(v, target), FALSE, tolerance, is.null(m))
