@@ -21,10 +21,15 @@ permuteGeneral <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
         return(.Call(`_RcppAlgos_CombinatoricsCnstrt`, v, m, repetition,
                      freqs, lower, upper, constraintFun, comparisonFun,
                      limitConstraints, FALSE, keepResults, Parallel,
-                     nThreads, pkgEnv$nThreads, tolerance))
+                     nThreads, pkgEnv$nThreads, tolerance, FALSE, FALSE))
     }
 }
 
+permuteRank <- function(..., v, repetition = FALSE, freqs = NULL) {
+    GetRank(..., v = v, repetition = repetition,
+            freqs = freqs, IsComb = FALSE)
+}
+
 permuteSample <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
                           n = NULL, sampleVec = NULL, seed = NULL,
                           FUN = NULL, Parallel = FALSE, nThreads = NULL,
@@ -55,8 +60,9 @@ permuteIter <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
                       keepResults, FUN)
     IsCnstrd <- .Call(`_RcppAlgos_CheckConstrndCpp`, constraintFun,
                       comparisonFun, limitConstraints)
-    InitVals <- .Call(`_RcppAlgos_GetClassVals`, v, m, repetition, freqs,
-                      FALSE, FUN, nThreads, pkgEnv$nThreads, IsCnstrd)
+    InitVals <- .Call(`_RcppAlgos_GetClassVals`, v, m, repetition,
+                      freqs, FALSE, FUN, nThreads, pkgEnv$nThreads,
+                      IsCnstrd, FALSE, FALSE)
 
     if (RetValue == 1) {
         new("Combo", InitVals, Parallel)
@@ -69,4 +75,4 @@ permuteIter <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
         new("ComboRes", InitVals, Parallel, constraintFun, comparisonFun,
             limitConstraints, keepResults, tolerance, is.null(m))
     }
-}
\ No newline at end of file
+}
