@@ -1,13 +1,10 @@
-#ifndef RANK_COMBINATION_H
-#define RANK_COMBINATION_H
+#pragma once
 
 #include <vector>
-#include <gmp.h>
+#include "CppConvert/GmpxxCopy.h"
 
 using rankCombPtr = void (*const)(std::vector<int>::iterator iter, int n,
-                          int m, double &dblIdx, mpz_t mpzIdx,
+                          int m, double &dblIdx, mpz_class &mpzIdx,
                           const std::vector<int> &Reps);
 
 rankCombPtr GetRankCombFunc(bool IsMult, bool IsRep, bool IsGmp);
-
-#endif
