@@ -1,14 +1,12 @@
-#ifndef MAIN_PERMUTATIONS_RESULT_H
-#define MAIN_PERMUTATIONS_RESULT_H
+#pragma once
 
 #include "Constraints/UserConstraintFuns.h"
-#include <gmp.h>
+#include "CppConvert/GmpxxCopy.h"
 
 template <typename T>
 void PermuteResMain(T* mat, const std::vector<T> &v, const funcPtr<T> myFun,
                     int n, int m, bool Parallel, bool IsRep, bool IsMult,
                     bool IsGmp, const std::vector<int> &freqs,
                     std::vector<int> &z, const std::vector<int> &myReps,
-                    double lower, mpz_t lowerMpz, int nRows, int nThreads);
-
-#endif
+                    double lower, mpz_class &lowerMpz,
+                    int nRows, int nThreads);
